from typing import Literal, cast

RecordState = Literal[0, 1, 2, 3, 4]

RECORD_STATE_VALUES: set[RecordState] = { 0, 1, 2, 3, 4,  }

def check_record_state(value: int) -> RecordState:
    if value in RECORD_STATE_VALUES:
        return cast(RecordState, value)
    raise TypeError(f"Unexpected value {value!r}. Expected one of {RECORD_STATE_VALUES!r}")



from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.http_validation_problem_details import HttpValidationProblemDetails
from ...models.update_record_command import UpdateRecordCommand
from typing import cast



def _get_kwargs(
    record_id: str,
    *,
    body: UpdateRecordCommand,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "put",
        "url": "/api/Records/{record_id}".format(record_id=record_id,),
    }

    _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[Any, HttpValidationProblemDetails, str]]:
    if response.status_code == 200:
        response_200 = cast(str, response.json())
        return response_200

    if response.status_code == 400:
        response_400 = HttpValidationProblemDetails.from_dict(response.json())



        return response_400

    if response.status_code == 404:
        response_404 = cast(Any, None)
        return response_404

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[Any, HttpValidationProblemDetails, str]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    record_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: UpdateRecordCommand,

) -> Response[Union[Any, HttpValidationProblemDetails, str]]:
    """ 
    Args:
        record_id (str):
        body (UpdateRecordCommand):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HttpValidationProblemDetails, str]]
     """


    kwargs = _get_kwargs(
        record_id=record_id,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    record_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: UpdateRecordCommand,

) -> Optional[Union[Any, HttpValidationProblemDetails, str]]:
    """ 
    Args:
        record_id (str):
        body (UpdateRecordCommand):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HttpValidationProblemDetails, str]
     """


    return sync_detailed(
        record_id=record_id,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    record_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: UpdateRecordCommand,

) -> Response[Union[Any, HttpValidationProblemDetails, str]]:
    """ 
    Args:
        record_id (str):
        body (UpdateRecordCommand):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HttpValidationProblemDetails, str]]
     """


    kwargs = _get_kwargs(
        record_id=record_id,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    record_id: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: UpdateRecordCommand,

) -> Optional[Union[Any, HttpValidationProblemDetails, str]]:
    """ 
    Args:
        record_id (str):
        body (UpdateRecordCommand):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HttpValidationProblemDetails, str]
     """


    return (await asyncio_detailed(
        record_id=record_id,
client=client,
body=body,

    )).parsed
